@@ -2,7 +2,7 @@ package App::ModuleBuildTiny::Dist;
 
 use 5.014;
 use warnings;
-our $VERSION = '0.044';
+our $VERSION = '0.047';
 
 use CPAN::Meta;
 use Config;
@@ -150,10 +150,10 @@ sub preflight_check {
 }
 
 sub scan_files {
-	my ($files, $omit) = @_;
+	my ($files, $omit, %extra_args) = @_;
 	my $combined = CPAN::Meta::Requirements->new;
 	require Perl::PrereqScanner;
-	my $scanner = Perl::PrereqScanner->new;
+	my $scanner = Perl::PrereqScanner->new(\%extra_args);
 	for my $file (@{$files}) {
 		my $prereqs = $scanner->scan_file($file);
 		$combined->add_requirements($prereqs);
@@ -164,7 +164,7 @@ sub scan_files {
 
 sub _scan_prereqs {
 	my ($omit, %opts) = @_;
-	my (@runtime_files, @test_files);
+	my (@runtime_files, @test_files, @planner_files);
 	File::Find::find(sub { push @runtime_files, $File::Find::name if -f && /\.pm$/ }, 'lib') if -d 'lib';
 	File::Find::find(sub { push @runtime_files, $File::Find::name if -f }, 'script') if -d 'script';
 	File::Find::find(sub { push @test_files, $File::Find::name if -f && /\.(t|pm)$/ }, 't') if -d 't';
@@ -172,11 +172,22 @@ sub _scan_prereqs {
 	my $runtime = scan_files(\@runtime_files, $omit);
 	my $test = scan_files(\@test_files, $omit);
 
-	my $prereqs = CPAN::Meta::Prereqs->new({
-		runtime   => { requires => $runtime->as_string_hash },
-		test      => { requires => $test->as_string_hash },
-		configure => { requires => { 'Module::Build::Tiny' => mbt_version() } },
-	});
+	my %prereqs = (
+		runtime => { requires => $runtime->as_string_hash },
+		test    => { requires => $test->as_string_hash },
+	);
+
+	if (-d 'planner') {
+		File::Find::find(sub { push @planner_files, $File::Find::name if -f && /\.pl$/ }, 'planner');
+		require Perl::PrereqScanner::Scanner::DistBuild;
+		my $configure = scan_files(\@planner_files, ['strict', 'warnings', @{$omit}], extra_scanners => [ 'DistBuild' ]);
+		$configure->add_minimum('Dist::Build' => '0.003');
+		$prereqs{configure} = { requires => $configure->as_string_hash };
+	} else {
+		$prereqs{configure} = { requires => { 'Module::Build::Tiny' => mbt_version() } };
+	}
+
+	my $prereqs = CPAN::Meta::Prereqs->new(\%prereqs);
 	require CPAN::Meta::Prereqs::Filter;
 	return CPAN::Meta::Prereqs::Filter::filter_prereqs($prereqs, %opts);
 }
@@ -232,13 +243,19 @@ sub new {
 	my $license = detect_license($pod_data, $filename, \@authors, $mergedata);
 
 	my $load_meta = !%{ $opts{regenerate} // {} } && uptodate('META.json', 'cpanfile', 'prereqs.json', 'prereqs.yml', $mergefile);
+
+	my $mode = -d 'planner' ? 'DB' : 'MBT';
 	my $meta = $load_meta ? CPAN::Meta->load_file('META.json', { lazy_validation => 0 }) : do {
 		my ($abstract) = ($pod_data->pod('NAME') // '')  =~ / \A \s+ \S+ \s? - \s? (.+?) \s* \z /x or warn "Could not parse abstract from `=head1 NAME` in $filename";
 		my $version = $data->version($data->name) // die "Cannot parse \$VERSION from $filename";
 
 		my $provides = Module::Metadata->provides(version => 2, dir => 'lib');
 		my $prereqs = load_prereqs($provides, %opts);
-		$prereqs->{configure}{requires}{'Module::Build::Tiny'} //= mbt_version();
+		if ($mode eq 'MBT') {
+			$prereqs->{configure}{requires}{'Module::Build::Tiny'} //= mbt_version();
+		} else {
+			$prereqs->{configure}{requires}{'Dist::Build'} //= '0.003';
+		}
 		$prereqs->{develop}{requires}{'App::ModuleBuildTiny'} //= $VERSION;
 		my %resources = $class->generate_resources(%opts);
 
@@ -299,9 +316,15 @@ sub new {
 	
 	my $dist_name = $meta->name;
 	$files{'Build.PL'} //= do {
-		my $minimum_mbt  = prereqs_for($meta, qw/configure requires Module::Build::Tiny/);
 		my $minimum_perl = prereqs_for($meta, qw/runtime requires perl 5.008/);
-		"# This Build.PL for $dist_name was generated by mbtiny $VERSION.\nuse $minimum_perl;\nuse Module::Build::Tiny $minimum_mbt;\nBuild_PL();\n";
+		my $header = "# This Build.PL for $dist_name was generated by mbtiny $VERSION.";
+		if ($mode eq 'MBT') {
+			my $minimum_mbt = prereqs_for($meta, qw/configure requires Module::Build::Tiny/);
+			"$header\nuse $minimum_perl;\nuse Module::Build::Tiny $minimum_mbt;\nBuild_PL();\n";
+		} else {
+			my $minimum_db = prereqs_for($meta, qw/configure requires Dist::Build/);
+			"$header\nuse $minimum_perl;\nuse Dist::Build $minimum_db;\nBuild_PL(\\\@ARGV, \\\%ENV);\n";
+		}
 	};
 	$files{'META.json'} //= $meta->as_string;
 	$files{'META.yml'} //= $meta->as_string({ version => 1.4 });
@@ -392,7 +415,7 @@ sub write_tarball {
 	for my $filename ($self->files) {
 		$arch->add_data($filename, $self->get_file($filename), { mode => oct '0644'} );
 	}
-	$arch->write($name, &Archive::Tar::COMPRESS_GZIP, $name);
+	$arch->write($name, &Archive::Tar::COMPRESS_GZIP, $name =~ s/.tar.gz$//r);
 	return $name;
 }
 
